"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.clone = exports.rmDirSync = exports.tempDir = void 0;
const fs_1 = require("fs");
const tempy = require("tempy");
const nodegit_1 = require("nodegit");
exports.tempDir = () => tempy.directory();
exports.rmDirSync = (path) => {
    if (fs_1.existsSync(path)) {
        fs_1.readdirSync(path).forEach((file) => {
            const curPath = path + "/" + file;
            if (fs_1.lstatSync(curPath).isDirectory()) {
                // recurse
                exports.rmDirSync(curPath);
            }
            else {
                // delete file
                fs_1.unlinkSync(curPath);
            }
        });
        fs_1.rmdirSync(path);
    }
};
exports.clone = async (ctx, url) => {
    const urlParts = url.split("/");
    const cloneDir = `${ctx.rootDirectory}/${urlParts[urlParts.length - 1].replace(".git", "")}`;
    ctx.log.debug(`cloning ${url} to ${cloneDir}`);
    await nodegit_1.Clone.clone(url, cloneDir, {
        fetchOpts: {
            callbacks: {
                certificateCheck: () => 1,
                credentials: () => nodegit_1.Cred.userpassPlaintextNew(process.env.GITHUB_ACCESS_TOKEN || "", "x-oauth-basic"),
            },
        },
    });
};
